==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/ti.pl <==
{
  am_pm_abbreviated => [
    "\N{U+1245}.\N{U+1240}.",
    "\N{U+12f5}.\N{U+1240}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E\N{U+1363} HH:mm",
    EHms => "E\N{U+1363} HH:mm:ss",
    Ed => "E d",
    Ehm => "E\N{U+1363} h:mm a",
    Ehms => "E\N{U+1363} h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E\N{U+1363} d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E\N{U+1363} d/M",
    MMM => "LLL",
    MMMEd => "E\N{U+1363} d MMM",
    "MMMMW-count-one" => "\N{U+1230}\N{U+1219}\N{U+1295} W \N{U+1293}\N{U+12ed} MMMM",
    "MMMMW-count-other" => "\N{U+1230}\N{U+1219}\N{U+1295} W \N{U+1293}\N{U+12ed} MMMM",
    MMMMd => "d MMMM",
    MMMMdd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "d/M",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E\N{U+1363} d/M/y",
    yMM => "M/y",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "\N{U+1230}\N{U+1219}\N{U+1295} w \N{U+1293}\N{U+12ed} Y",
    "yw-count-other" => "\N{U+1230}\N{U+1219}\N{U+1295} w \N{U+1293}\N{U+12ed} Y",
  },
  code => "ti",
  date_format_full => "EEEE\N{U+1363} d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} \N{U+1230}\N{U+12d3}\N{U+1275} {0}",
  datetime_format_long => "{1} \N{U+1230}\N{U+12d3}\N{U+1275} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+1230}\N{U+1291}",
    "\N{U+1230}\N{U+1209}",
    "\N{U+1228}\N{U+1261}",
    "\N{U+1213}\N{U+1219}",
    "\N{U+12d3}\N{U+122d}",
    "\N{U+1240}\N{U+12f3}",
    "\N{U+1230}\N{U+1295}",
  ],
  day_format_narrow => [
    "\N{U+1230}",
    "\N{U+1230}",
    "\N{U+1228}",
    "\N{U+1213}",
    "\N{U+12d3}",
    "\N{U+1240}",
    "\N{U+1230}",
  ],
  day_format_wide => [
    "\N{U+1230}\N{U+1291}\N{U+12ed}",
    "\N{U+1230}\N{U+1209}\N{U+1235}",
    "\N{U+1228}\N{U+1261}\N{U+12d5}",
    "\N{U+1213}\N{U+1219}\N{U+1235}",
    "\N{U+12d3}\N{U+122d}\N{U+1262}",
    "\N{U+1240}\N{U+12f3}\N{U+121d}",
    "\N{U+1230}\N{U+1295}\N{U+1260}\N{U+1275}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+1230}\N{U+1291}",
    "\N{U+1230}\N{U+1209}",
    "\N{U+1228}\N{U+1261}",
    "\N{U+1213}\N{U+1219}",
    "\N{U+12d3}\N{U+122d}",
    "\N{U+1240}\N{U+12f3}",
    "\N{U+1230}\N{U+1295}",
  ],
  day_stand_alone_narrow => [
    "\N{U+1230}",
    "\N{U+1230}",
    "\N{U+1228}",
    "\N{U+1213}",
    "\N{U+12d3}",
    "\N{U+1240}",
    "\N{U+1230}",
  ],
  day_stand_alone_wide => [
    "\N{U+1230}\N{U+1291}\N{U+12ed}",
    "\N{U+1230}\N{U+1209}\N{U+1235}",
    "\N{U+1228}\N{U+1261}\N{U+12d5}",
    "\N{U+1213}\N{U+1219}\N{U+1235}",
    "\N{U+12d3}\N{U+122d}\N{U+1262}",
    "\N{U+1240}\N{U+12f3}\N{U+121d}",
    "\N{U+1230}\N{U+1295}\N{U+1260}\N{U+1275}",
  ],
  era_abbreviated => [
    "\N{U+12d3}/\N{U+12d3}",
    "\N{U+12d3}/\N{U+121d}",
  ],
  era_narrow => [
    "\N{U+12d3}/\N{U+12d3}",
    "\N{U+12d3}/\N{U+121d}",
  ],
  era_wide => [
    "\N{U+1245}\N{U+12f5}\N{U+1218} \N{U+12ad}\N{U+122d}\N{U+1235}\N{U+1276}\N{U+1235}",
    "\N{U+12d3}\N{U+1218}\N{U+1270} \N{U+121d}\N{U+1215}\N{U+1228}\N{U+1275}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tigrinya",
  month_format_abbreviated => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}",
    "\N{U+1218}\N{U+130b}",
    "\N{U+121a}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}",
    "\N{U+1290}\N{U+1213}",
    "\N{U+1218}\N{U+1235}",
    "\N{U+1325}\N{U+1245}",
    "\N{U+1215}\N{U+12f3}",
    "\N{U+1273}\N{U+1215}",
  ],
  month_format_narrow => [
    "\N{U+1325}",
    "\N{U+1208}",
    "\N{U+1218}",
    "\N{U+121a}",
    "\N{U+130d}",
    "\N{U+1230}",
    "\N{U+1213}",
    "\N{U+1290}",
    "\N{U+1218}",
    "\N{U+1325}",
    "\N{U+1215}",
    "\N{U+1273}",
  ],
  month_format_wide => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}\N{U+1272}\N{U+1275}",
    "\N{U+1218}\N{U+130b}\N{U+1262}\N{U+1275}",
    "\N{U+121a}\N{U+12eb}\N{U+12dd}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}\N{U+1266}\N{U+1275}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}\N{U+1208}",
    "\N{U+1290}\N{U+1213}\N{U+1230}",
    "\N{U+1218}\N{U+1235}\N{U+12a8}\N{U+1228}\N{U+121d}",
    "\N{U+1325}\N{U+1245}\N{U+121d}\N{U+1272}",
    "\N{U+1215}\N{U+12f3}\N{U+122d}",
    "\N{U+1273}\N{U+1215}\N{U+1233}\N{U+1235}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}",
    "\N{U+1218}\N{U+130b}",
    "\N{U+121a}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}",
    "\N{U+1290}\N{U+1213}",
    "\N{U+1218}\N{U+1235}",
    "\N{U+1325}\N{U+1245}",
    "\N{U+1215}\N{U+12f3}",
    "\N{U+1273}\N{U+1215}",
  ],
  month_stand_alone_narrow => [
    "\N{U+1325}",
    "\N{U+1208}",
    "\N{U+1218}",
    "\N{U+121a}",
    "\N{U+130d}",
    "\N{U+1230}",
    "\N{U+1213}",
    "\N{U+1290}",
    "\N{U+1218}",
    "\N{U+1325}",
    "\N{U+1215}",
    "\N{U+1273}",
  ],
  month_stand_alone_wide => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}\N{U+1272}\N{U+1275}",
    "\N{U+1218}\N{U+130b}\N{U+1262}\N{U+1275}",
    "\N{U+121a}\N{U+12eb}\N{U+12dd}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}\N{U+1266}\N{U+1275}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}\N{U+1208}",
    "\N{U+1290}\N{U+1213}\N{U+1230}",
    "\N{U+1218}\N{U+1235}\N{U+12a8}\N{U+1228}\N{U+121d}",
    "\N{U+1325}\N{U+1245}\N{U+121d}\N{U+1272}",
    "\N{U+1215}\N{U+12f3}\N{U+122d}",
    "\N{U+1273}\N{U+1215}\N{U+1233}\N{U+1235}",
  ],
  name => "Tigrinya",
  native_language => "\N{U+1275}\N{U+130d}\N{U+122d}\N{U+129b}",
  native_name => "\N{U+1275}\N{U+130d}\N{U+122d}\N{U+129b}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+122d}1",
    "\N{U+122d}2",
    "\N{U+122d}3",
    "\N{U+122d}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "2\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "3\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "4\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+122d}1",
    "\N{U+122d}2",
    "\N{U+122d}3",
    "\N{U+122d}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "2\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "3\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "4\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/ti.pl <==
{
  am_pm_abbreviated => [
    "\N{U+1245}.\N{U+1240}.",
    "\N{U+12f5}.\N{U+1240}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E\N{U+1363} HH:mm",
    EHms => "E\N{U+1363} HH:mm:ss",
    Ed => "E d",
    Ehm => "E\N{U+1363} h:mm a",
    Ehms => "E\N{U+1363} h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E\N{U+1363} d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E\N{U+1363} d/M",
    MMM => "LLL",
    MMMEd => "E\N{U+1363} d MMM",
    "MMMMW-count-one" => "\N{U+1230}\N{U+1219}\N{U+1295} W \N{U+1293}\N{U+12ed} MMMM",
    "MMMMW-count-other" => "\N{U+1230}\N{U+1219}\N{U+1295} W \N{U+1293}\N{U+12ed} MMMM",
    MMMMd => "d MMMM",
    MMMMdd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "d/M",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E\N{U+1363} d/M/y",
    yMM => "M/y",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "\N{U+1230}\N{U+1219}\N{U+1295} w \N{U+1293}\N{U+12ed} Y",
    "yw-count-other" => "\N{U+1230}\N{U+1219}\N{U+1295} w \N{U+1293}\N{U+12ed} Y",
  },
  code => "ti",
  date_format_full => "EEEE\N{U+1363} d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+1230}\N{U+1291}",
    "\N{U+1230}\N{U+1209}",
    "\N{U+1228}\N{U+1261}",
    "\N{U+1213}\N{U+1219}",
    "\N{U+12d3}\N{U+122d}",
    "\N{U+1240}\N{U+12f3}",
    "\N{U+1230}\N{U+1295}",
  ],
  day_format_narrow => [
    "\N{U+1230}",
    "\N{U+1230}",
    "\N{U+1228}",
    "\N{U+1213}",
    "\N{U+12d3}",
    "\N{U+1240}",
    "\N{U+1230}",
  ],
  day_format_wide => [
    "\N{U+1230}\N{U+1291}\N{U+12ed}",
    "\N{U+1230}\N{U+1209}\N{U+1235}",
    "\N{U+1228}\N{U+1261}\N{U+12d5}",
    "\N{U+1213}\N{U+1219}\N{U+1235}",
    "\N{U+12d3}\N{U+122d}\N{U+1262}",
    "\N{U+1240}\N{U+12f3}\N{U+121d}",
    "\N{U+1230}\N{U+1295}\N{U+1260}\N{U+1275}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+1230}\N{U+1291}",
    "\N{U+1230}\N{U+1209}",
    "\N{U+1228}\N{U+1261}",
    "\N{U+1213}\N{U+1219}",
    "\N{U+12d3}\N{U+122d}",
    "\N{U+1240}\N{U+12f3}",
    "\N{U+1230}\N{U+1295}",
  ],
  day_stand_alone_narrow => [
    "\N{U+1230}",
    "\N{U+1230}",
    "\N{U+1228}",
    "\N{U+1213}",
    "\N{U+12d3}",
    "\N{U+1240}",
    "\N{U+1230}",
  ],
  day_stand_alone_wide => [
    "\N{U+1230}\N{U+1291}\N{U+12ed}",
    "\N{U+1230}\N{U+1209}\N{U+1235}",
    "\N{U+1228}\N{U+1261}\N{U+12d5}",
    "\N{U+1213}\N{U+1219}\N{U+1235}",
    "\N{U+12d3}\N{U+122d}\N{U+1262}",
    "\N{U+1240}\N{U+12f3}\N{U+121d}",
    "\N{U+1230}\N{U+1295}\N{U+1260}\N{U+1275}",
  ],
  era_abbreviated => [
    "\N{U+12d3}/\N{U+12d3}",
    "\N{U+12d3}/\N{U+121d}",
  ],
  era_narrow => [
    "\N{U+12d3}/\N{U+12d3}",
    "\N{U+12d3}/\N{U+121d}",
  ],
  era_wide => [
    "\N{U+1245}\N{U+12f5}\N{U+1218} \N{U+12ad}\N{U+122d}\N{U+1235}\N{U+1276}\N{U+1235}",
    "\N{U+12d3}\N{U+1218}\N{U+1270} \N{U+121d}\N{U+1215}\N{U+1228}\N{U+1275}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tigrinya",
  month_format_abbreviated => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}",
    "\N{U+1218}\N{U+130b}",
    "\N{U+121a}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}",
    "\N{U+1290}\N{U+1213}",
    "\N{U+1218}\N{U+1235}",
    "\N{U+1325}\N{U+1245}",
    "\N{U+1215}\N{U+12f3}",
    "\N{U+1273}\N{U+1215}",
  ],
  month_format_narrow => [
    "\N{U+1325}",
    "\N{U+1208}",
    "\N{U+1218}",
    "\N{U+121a}",
    "\N{U+130d}",
    "\N{U+1230}",
    "\N{U+1213}",
    "\N{U+1290}",
    "\N{U+1218}",
    "\N{U+1325}",
    "\N{U+1215}",
    "\N{U+1273}",
  ],
  month_format_wide => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}\N{U+1272}\N{U+1275}",
    "\N{U+1218}\N{U+130b}\N{U+1262}\N{U+1275}",
    "\N{U+121a}\N{U+12eb}\N{U+12dd}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}\N{U+1266}\N{U+1275}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}\N{U+1208}",
    "\N{U+1290}\N{U+1213}\N{U+1230}",
    "\N{U+1218}\N{U+1235}\N{U+12a8}\N{U+1228}\N{U+121d}",
    "\N{U+1325}\N{U+1245}\N{U+121d}\N{U+1272}",
    "\N{U+1215}\N{U+12f3}\N{U+122d}",
    "\N{U+1273}\N{U+1215}\N{U+1233}\N{U+1235}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}",
    "\N{U+1218}\N{U+130b}",
    "\N{U+121a}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}",
    "\N{U+1290}\N{U+1213}",
    "\N{U+1218}\N{U+1235}",
    "\N{U+1325}\N{U+1245}",
    "\N{U+1215}\N{U+12f3}",
    "\N{U+1273}\N{U+1215}",
  ],
  month_stand_alone_narrow => [
    "\N{U+1325}",
    "\N{U+1208}",
    "\N{U+1218}",
    "\N{U+121a}",
    "\N{U+130d}",
    "\N{U+1230}",
    "\N{U+1213}",
    "\N{U+1290}",
    "\N{U+1218}",
    "\N{U+1325}",
    "\N{U+1215}",
    "\N{U+1273}",
  ],
  month_stand_alone_wide => [
    "\N{U+1325}\N{U+122a}",
    "\N{U+1208}\N{U+12ab}\N{U+1272}\N{U+1275}",
    "\N{U+1218}\N{U+130b}\N{U+1262}\N{U+1275}",
    "\N{U+121a}\N{U+12eb}\N{U+12dd}\N{U+12eb}",
    "\N{U+130d}\N{U+1295}\N{U+1266}\N{U+1275}",
    "\N{U+1230}\N{U+1290}",
    "\N{U+1213}\N{U+121d}\N{U+1208}",
    "\N{U+1290}\N{U+1213}\N{U+1230}",
    "\N{U+1218}\N{U+1235}\N{U+12a8}\N{U+1228}\N{U+121d}",
    "\N{U+1325}\N{U+1245}\N{U+121d}\N{U+1272}",
    "\N{U+1215}\N{U+12f3}\N{U+122d}",
    "\N{U+1273}\N{U+1215}\N{U+1233}\N{U+1235}",
  ],
  name => "Tigrinya",
  native_language => "\N{U+1275}\N{U+130d}\N{U+122d}\N{U+129b}",
  native_name => "\N{U+1275}\N{U+130d}\N{U+122d}\N{U+129b}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+122d}1",
    "\N{U+122d}2",
    "\N{U+122d}3",
    "\N{U+122d}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "2\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "3\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "4\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+122d}1",
    "\N{U+122d}2",
    "\N{U+122d}3",
    "\N{U+122d}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "2\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "3\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
    "4\N{U+12ed} \N{U+122d}\N{U+1265}\N{U+12d2}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => "44.1",
}
